==> rnu34.db_2.2.0.tar.gz: rnu34.db/man/rnu34_dbconn.Rd <==
\name{rnu34_dbconn}

\alias{rnu34_dbconn}
\alias{rnu34_dbfile}
\alias{rnu34_dbschema}
\alias{rnu34_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rnu34_dbconn()
  rnu34_dbfile()
  rnu34_dbschema(file="", show.indices=FALSE)
  rnu34_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rnu34_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{rnu34_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{rnu34_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rnu34_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rnu34_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rnu34_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{rnu34_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rnu34_dbschema}: none (invisible \code{NULL}).

  \code{rnu34_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rnu34_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rnu34_dbconn() was created with:
  dbConnect(SQLite(), dbname=rnu34_dbfile(), cache_size=64000, synchronous=0)

  rnu34_dbschema()

  rnu34_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> rnu34.db_2.9.0.tar.gz: rnu34.db/man/rnu34_dbconn.Rd <==

\name{rnu34_dbconn}

\alias{rnu34_dbconn}
\alias{rnu34_dbfile}
\alias{rnu34_dbschema}
\alias{rnu34_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rnu34_dbconn()
  rnu34_dbfile()
  rnu34_dbschema(file="", show.indices=FALSE)
  rnu34_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rnu34_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{rnu34_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{rnu34_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rnu34_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rnu34_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rnu34_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{rnu34_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rnu34_dbschema}: none (invisible \code{NULL}).

  \code{rnu34_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rnu34_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rnu34_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=rnu34_dbfile(), cache_size=64000,
  synchronous=0)

  rnu34_dbschema()

  rnu34_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
